@@ -1,9 +1,9 @@
 package TAP::DOM;
-# git description: v0.95-1-gbc23f2e
+# git description: v0.96-1-g9b41662
 
 our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: TAP as Document Object Model.
-$TAP::DOM::VERSION = '0.96';
+$TAP::DOM::VERSION = '0.97';
 use 5.006;
 use strict;
 use warnings;
@@ -123,7 +123,7 @@ $severity->{test}     {0}        {0}            {0}        {1} = 6; # notok_skip
 
 our $obvious_tap_line = qr/(1\.\.|ok\s|not\s+ok\s|#|\s|tap\s+version|pragma|Bail out!)/i;
 
-our $noempty_tap = "+pragma tapdom_error\n# document was empty";
+our $noempty_tap = "pragma +tapdom_error\n# document was empty";
 
 use Class::XSAccessor
     chained     => 1,
@@ -1040,7 +1040,7 @@ careful!
 When a document is empty (which can also happen after preprocessing)
 then this option set to 1 triggers to put in some replacement line.
 
- +pragma tapdom_error
+ pragma +tapdom_error
  # document was empty
 
 which in turn assigns it an error severity, so that these situations
